@@ -19,6 +19,7 @@ from typing import Optional
 from tornado_sqlalchemy import SQLAlchemy
 
 from lesscode.db.init_connection_pool import InitConnectionPool
+from lesscode.extend_handlers.not_found_handler import NotFoundHandler
 from lesscode.web.router_mapping import RouterMapping
 
 define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
@@ -126,6 +127,7 @@ class WebServer:
         if options.scheduler_config.get("enable", False):
             self.init_scheduler()
         handlers = options.restful_handler + RouterMapping.instance()
+        handlers.append(('.*', NotFoundHandler))
         self.app = tornado.web.Application(
             handlers,
             cookie_secret=options.cookie_secret,
